==> owncloud-8.1.0p2.tgz: owncloud/lib/l10n/sl.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Mapa 'config' nima določenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo.",
    "See %s" : "Oglejte si %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Napako je mogoče odpraviti z %sdodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo%s.",
    "Sample configuration detected" : "Zaznana je neustrezna preizkusna nastavitev",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zaznano je, da je bila v sistem kopirana datoteka z enostavno nastavitvijo. To lahko vpliva na namestitev in zato možnost ni podprta. Pred spremembami datoteke config.php si natančno preberite dokumentacijo.",
    "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
    "PHP with a version lower than %s is required." : "Zahtevana je različica PHP manj kot %s.",
    "Following databases are supported: %s" : "Podprte so navedene podatkovne zbirke: %s",
    "The command line tool %s could not be found" : "Orodja ukazne vrstice %s ni mogoče najti",
    "The library %s is not available." : "Knjižnica %s ni na voljo.",
    "Library %s with a version higher than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, višjo od %s – na voljo je različica %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, manjšo od %s – na voljo je različica %s.",
    "Following platforms are supported: %s" : "Podprta so okolja: %s",
    "ownCloud %s or higher is required." : "Zahtevana je različica ownCloud %s ali višja.",
    "ownCloud with a version lower than %s is required." : "Zahtevana je različica ownCloud %s ali nižja.",
    "Help" : "Pomoč",
    "Personal" : "Osebno",
    "Users" : "Uporabniki",
    "Admin" : "Skrbništvo",
    "Recommended" : "Priporočljivo",
    "No app name specified" : "Ni podanega imena programa",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "today" : "danes",
    "yesterday" : "včeraj",
    "_%n day ago_::_%n days ago_" : ["pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"],
    "last month" : "zadnji mesec",
    "_%n month ago_::_%n months ago_" : ["pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"],
    "last year" : "lansko leto",
    "_%n year ago_::_%n years ago_" : ["pred %n letom","pred %n letoma","pred %n leti","pred %n leti"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n uro","pred %n urama","pred %n urami","pred %n urami"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"],
    "seconds ago" : "pred nekaj sekundami",
    "web services under your control" : "spletne storitve pod vašim nadzorom",
    "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en neveljaven znak.",
    "File name is too long" : "Ime datoteke je predolgo",
    "Can't read file" : "Datoteke ni mogoče prebrati.",
    "App directory already exists" : "Programska mapa že obstaja",
    "Can't create app folder. Please fix permissions. %s" : "Programske mape ni mogoče ustvariti. Ni ustreznih dovoljenj. %s",
    "No source specified when installing app" : "Ni podanega vira med nameščenjem programa",
    "No href specified when installing app from http" : "Ni podanega podatka naslova HREF med nameščenjem programa preko protokola HTTP.",
    "No path specified when installing app from local file" : "Ni podane poti med nameščenjem programa iz krajevne datoteke",
    "Archives of type %s are not supported" : "Arhivi vrste %s niso podprti",
    "Failed to open archive when installing app" : "Odpiranje arhiva je med nameščanjem spodletelo",
    "App does not provide an info.xml file" : "Program je brez datoteke info.xml",
    "App can't be installed because of not allowed code in the App" : "Programa ni mogoče namestiti zaradi nedovoljene programske kode.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Programa ni mogoče namestiti, ker ni skladen z trenutno nameščeno različico oblaka ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Programa ni mogoče namestiti, ker vsebuje oznako <shipped>potrditve</shipped>, ki pa ni dovoljena za javne programe.",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Program ni mogoče namestiti zaradi neustrezne različice datoteke info.xml. Ta ni enaka različici programa.",
    "Application is not enabled" : "Program ni omogočen",
    "Authentication error" : "Napaka overjanja",
    "Token expired. Please reload page." : "Žeton je potekel. Stran je treba ponovno naložiti.",
    "Unknown user" : "Neznan uporabnik",
    "%s enter the database username." : "%s - vnos uporabniškega imena podatkovne zbirke.",
    "%s enter the database name." : "%s - vnos imena podatkovne zbirke.",
    "%s you may not use dots in the database name" : "%s - v imenu podatkovne zbirke ni dovoljeno uporabljati pik.",
    "MS SQL username and/or password not valid: %s" : "Uporabniško ime ali geslo MS SQL ni veljavno: %s",
    "You need to enter either an existing account or the administrator." : "Prijaviti se je treba v obstoječi ali pa skrbniški račun.",
    "MySQL/MariaDB username and/or password not valid" : "Uporabniško ime ali geslo za MySQL/MariaDB ni veljavno",
    "DB Error: \"%s\"" : "Napaka podatkovne zbirke: \"%s\"",
    "Offending command was: \"%s\"" : "Napačni ukaz je: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "Uporabnik podatkovne zbirke MySQL/MariaDB '%s'@'localhost' že obstaja.",
    "Drop this user from MySQL/MariaDB" : "Odstrani uporabnika iz podatkovne zbirke MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "Uporabnik podatkovne zbirke MySQL/MariaDB '%s'@'%%' že obstaja.",
    "Drop this user from MySQL/MariaDB." : "Odstrani uporabnika iz podatkovne zbirke MySQL/MariaDB.",
    "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
    "Offending command was: \"%s\", name: %s, password: %s" : "Napačni ukaz je: \"%s\", ime: %s, geslo: %s",
    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolj še rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
    "Set an admin password." : "Nastavi geslo skrbnika.",
    "Can't create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
    "%s shared »%s« with you" : "%s je omogočil souporabo »%s«",
    "%s via %s" : "%s prek %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %i.",
    "Sharing %s failed, because the file does not exist" : "Souporaba %s je spodletela, ker ta datoteka ne obstaja",
    "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
    "Sharing %s failed, because the user %s is the item owner" : "Nastavljanje souporabe %s je spodletelo, ker je uporabnik %s lastnik predmeta.",
    "Sharing %s failed, because the user %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ne obstaja.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član nobene skupine, v kateri je tudi uporabnik %s.",
    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletela, ker je ima uporabnik %s predmet že v souporabi.",
    "Sharing %s failed, because the group %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker je skupina %s ne obstaja.",
    "Sharing %s failed, because %s is not a member of the group %s" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član skupine %s.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Navesti je treba geslo za ustvarjanje javne povezave, saj so dovoljene le zaščitene.",
    "Sharing %s failed, because sharing with links is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker souporaba preko povezave ni dovoljena.",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Omogočanje souporabe %s je spodletelo, ker ni mogoče najti %s. Najverjetneje je strežnik nedosegljiv.",
    "Share type %s is not valid for %s" : "Vrsta souporabe %s za %s ni veljavna.",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje dovoljenj za %s je spodletelo, saj ta presegajo dovoljenja dodeljena uporabniku %s.",
    "Setting permissions for %s failed, because the item was not found" : "Nastavljanje dovoljenj za %s je spodletelo, ker predmeta ni mogoče najti.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ni mogoče določiti datuma preteka. Ni dovoljeno, da so mape ali datoteke, dodeljene v souporabo, v souporabi po %s.",
    "Cannot set expiration date. Expiration date is in the past" : "Ni mogoče nastaviti datuma preteka. Ta datum je že preteklost.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
    "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
    "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
    "Sharing %s failed, because the user %s is the original sharer" : "Nastavljanje souporabe %s je spodletelo, ker je uporabnik %s omogočil souporabo predmeta.",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje souporabe %s je spodletelo, ker zahteve presegajo dodeljena dovoljenja za %s.",
    "Sharing %s failed, because resharing is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker nadaljnje omogočanje souporabe ni dovoljeno.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Nastavljanje souporabe %s je spodletelo, ker ozadnji program %s ne upravlja z viri.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Nastavljanje souporabe %s je spodletelo, ker v predpomnilniku zahtevana datoteka ne obstaja.",
    "Could not find category \"%s\"" : "Kategorije \"%s\" ni mogoče najti.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ni nameščenih programnikov podatkovnih zbirk (sqlite, mysql, ali postgresql).",
    "Microsoft Windows Platform is not supported" : "Okolje Microsoft Windows ni podprto.",
    "Cannot write into \"config\" directory" : "Mapa 'config' nima nastavljenih ustreznih dovoljenj za pisanje!",
    "Cannot write into \"apps\" directory" : "Mapa \"apps\" nima nastavljenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku %s za pisanje v mapo programov %s, ali pa z onemogočanjem nameščanja programov v nastavitveni datoteki.",
    "Cannot create \"data\" directory (%s)" : "Ni mogoče ustvariti\"podatkovne\" mape (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Napako je mogoče odpraviti z  <a href=\"%s\" target=\"_blank\">dodelitvijo dovoljenja spletnemu strežniku za pisanje v korensko mapo</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dovoljenja je mogoče odpraviti z %sdodelitvijo dovoljenja spletnemu strežniku za pisanje korensko mapo%s.",
    "Setting locale to %s failed" : "Nastavljanje jezikovnih določil na %s je spodletelo.",
    "Please install one of these locales on your system and restart your webserver." : "Namestiti je treba podporo za vsaj eno od navedenih jezikovnih določil v sistemu in nato ponovno zagnati spletni strežnik.",
    "Please ask your server administrator to install the module." : "Obvestite skrbnika strežnika, da je treba namestiti manjkajoč modul.",
    "PHP module %s not installed." : "Modul PHP %s ni nameščen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Nastavitev PHP \"%s\" ni nastavljena na \"%s\".",
    "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
    "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
    "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9.",
    "Please upgrade your database version" : "Posodobite različico podatkovne zbirke.",
    "Error occurred while checking PostgreSQL version" : "Prišlo je do napake med preverjanjem različice PostgreSQL.",
    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Prepričajte se, da je nameščena različica PostgreSQL >= 9 in preverite dnevniški zapis za več podrobnosti o napaki.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
    "Data directory (%s) is readable by other users" : "Podatkovna mapa (%s) ima določena dovoljenja za branje skupine.",
    "Data directory (%s) is invalid" : "Podatkovna mapa (%s) ni veljavna.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Preverite, ali je v korenu podatkovne mape datoteka \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "Ni mogoče pridobiti zaklepa %d na \"%s\"."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-9.0.3.tgz: owncloud/lib/l10n/sl.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Mapa 'config' nima določenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo.",
    "See %s" : "Oglejte si %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Napako je mogoče odpraviti z %sdodelitvijo dovoljenja spletnemu strežniku za pisanje v nastavitveno mapo%s.",
    "Sample configuration detected" : "Zaznana je neustrezna preizkusna nastavitev",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Zaznano je, da je bila v sistem kopirana datoteka z enostavno nastavitvijo. To lahko vpliva na namestitev in zato možnost ni podprta. Pred spremembami datoteke config.php si natančno preberite dokumentacijo.",
    "PHP %s or higher is required." : "Zahtevana je različica PHP %s ali višja.",
    "PHP with a version lower than %s is required." : "Zahtevana je različica PHP manj kot %s.",
    "Following databases are supported: %s" : "Podprte so navedene podatkovne zbirke: %s",
    "The command line tool %s could not be found" : "Orodja ukazne vrstice %s ni mogoče najti",
    "The library %s is not available." : "Knjižnica %s ni na voljo.",
    "Library %s with a version higher than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, višjo od %s – na voljo je različica %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Zahtevana je knjižnica %s z različico, manjšo od %s – na voljo je različica %s.",
    "Following platforms are supported: %s" : "Podprta so okolja: %s",
    "ownCloud %s or higher is required." : "Zahtevana je različica ownCloud %s ali višja.",
    "Help" : "Pomoč",
    "Personal" : "Osebno",
    "Users" : "Uporabniki",
    "Admin" : "Skrbništvo",
    "Recommended" : "Priporočljivo",
    "No app name specified" : "Ni podanega imena programa",
    "Unknown filetype" : "Neznana vrsta datoteke",
    "Invalid image" : "Neveljavna slika",
    "today" : "danes",
    "yesterday" : "včeraj",
    "_%n day ago_::_%n days ago_" : ["pred %n dnevom","pred %n dnevoma","pred %n dnevi","pred %n dnevi"],
    "last month" : "zadnji mesec",
    "_%n month ago_::_%n months ago_" : ["pred %n mesecem","pred %n mesecema","pred %n meseci","pred %n meseci"],
    "last year" : "lansko leto",
    "_%n year ago_::_%n years ago_" : ["pred %n letom","pred %n letoma","pred %n leti","pred %n leti"],
    "_%n hour ago_::_%n hours ago_" : ["pred %n uro","pred %n urama","pred %n urami","pred %n urami"],
    "_%n minute ago_::_%n minutes ago_" : ["pred %n minuto","pred %n minutama","pred %n minutami","pred %n minutami"],
    "seconds ago" : "pred nekaj sekundami",
    "web services under your control" : "spletne storitve pod vašim nadzorom",
    "Empty filename is not allowed" : "Prazno polje imena datoteke ni dovoljeno.",
    "Dot files are not allowed" : "Skrite datoteke niso dovoljene",
    "File name is a reserved word" : "Ime datoteke je zadržana beseda",
    "File name contains at least one invalid character" : "Ime datoteke vsebuje vsaj en neveljaven znak.",
    "File name is too long" : "Ime datoteke je predolgo",
    "File is currently busy, please try again later" : "Datoteka je trenutno v uporabi. Poskusite znova kasneje.",
    "Can't read file" : "Datoteke ni mogoče prebrati.",
    "App directory already exists" : "Programska mapa že obstaja",
    "Can't create app folder. Please fix permissions. %s" : "Programske mape ni mogoče ustvariti. Ni ustreznih dovoljenj. %s",
    "No source specified when installing app" : "Ni podanega vira med nameščenjem programa",
    "No href specified when installing app from http" : "Ni podanega podatka naslova HREF med nameščenjem programa preko protokola HTTP.",
    "No path specified when installing app from local file" : "Ni podane poti med nameščenjem programa iz krajevne datoteke",
    "Archives of type %s are not supported" : "Arhivi vrste %s niso podprti",
    "Failed to open archive when installing app" : "Odpiranje arhiva je med nameščanjem spodletelo",
    "App does not provide an info.xml file" : "Program je brez datoteke info.xml",
    "App can't be installed because of not allowed code in the App" : "Programa ni mogoče namestiti zaradi nedovoljene programske kode.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Programa ni mogoče namestiti, ker ni skladen z trenutno nameščeno različico oblaka ownCloud.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Programa ni mogoče namestiti, ker vsebuje oznako <shipped>potrditve</shipped>, ki pa ni dovoljena za javne programe.",
    "Application is not enabled" : "Program ni omogočen",
    "Authentication error" : "Napaka overjanja",
    "Token expired. Please reload page." : "Žeton je potekel. Stran je treba ponovno naložiti.",
    "Unknown user" : "Neznan uporabnik",
    "%s enter the database username." : "%s - vnos uporabniškega imena podatkovne zbirke.",
    "%s enter the database name." : "%s - vnos imena podatkovne zbirke.",
    "%s you may not use dots in the database name" : "%s - v imenu podatkovne zbirke ni dovoljeno uporabljati pik.",
    "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
    "DB Error: \"%s\"" : "Napaka podatkovne zbirke: \"%s\"",
    "Offending command was: \"%s\"" : "Napačni ukaz je: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Prijaviti se je treba v obstoječi ali pa skrbniški račun.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Napačni ukaz je: \"%s\", ime: %s, geslo: %s",
    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolj še rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
    "Set an admin password." : "Nastavi geslo skrbnika.",
    "Can't create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
    "Invalid Federated Cloud ID" : "Neveljaven ID za prenos dovoljenj ownCloud",
    "%s shared »%s« with you" : "%s je omogočil souporabo »%s«",
    "%s via %s" : "%s prek %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %i.",
    "Sharing %s failed, because the file does not exist" : "Souporaba %s je spodletela, ker ta datoteka ne obstaja",
    "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
    "Sharing %s failed, because the user %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ne obstaja.",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član nobene skupine, v kateri je tudi uporabnik %s.",
    "Sharing %s failed, because this item is already shared with %s" : "Nastavljanje souporabe %s je spodletela, ker je ima uporabnik %s predmet že v souporabi.",
    "Sharing %s failed, because the group %s does not exist" : "Nastavljanje souporabe %s je spodletelo, ker je skupina %s ne obstaja.",
    "Sharing %s failed, because %s is not a member of the group %s" : "Nastavljanje souporabe %s je spodletelo, ker uporabnik %s ni član skupine %s.",
    "You need to provide a password to create a public link, only protected links are allowed" : "Navesti je treba geslo za ustvarjanje javne povezave, saj so dovoljene le zaščitene.",
    "Sharing %s failed, because sharing with links is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker souporaba preko povezave ni dovoljena.",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti souporabe s prenosom dovoljenj z istim uporabnikom",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Omogočanje souporabe %s je spodletelo, ker ni mogoče najti %s. Najverjetneje je strežnik nedosegljiv.",
    "Share type %s is not valid for %s" : "Vrsta souporabe %s za %s ni veljavna.",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje dovoljenj za %s je spodletelo, saj ta presegajo dovoljenja dodeljena uporabniku %s.",
    "Setting permissions for %s failed, because the item was not found" : "Nastavljanje dovoljenj za %s je spodletelo, ker predmeta ni mogoče najti.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Ni mogoče določiti datuma preteka. Ni dovoljeno, da so mape ali datoteke, dodeljene v souporabo, v souporabi po %s.",
    "Cannot set expiration date. Expiration date is in the past" : "Ni mogoče nastaviti datuma preteka. Ta datum je že preteklost.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
    "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
    "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Nastavljanje souporabe %s je spodletelo, ker zahteve presegajo dodeljena dovoljenja za %s.",
    "Sharing %s failed, because resharing is not allowed" : "Nastavljanje souporabe %s je spodletelo, ker nadaljnje omogočanje souporabe ni dovoljeno.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Nastavljanje souporabe %s je spodletelo, ker ozadnji program %s ne upravlja z viri.",
    "Sharing %s failed, because the file could not be found in the file cache" : "Nastavljanje souporabe %s je spodletelo, ker v predpomnilniku zahtevana datoteka ne obstaja.",
    "Expiration date is in the past" : "Datum preteka je že mimo!",
    "Could not find category \"%s\"" : "Kategorije \"%s\" ni mogoče najti.",
    "Apps" : "Programi",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ni nameščenih programnikov podatkovnih zbirk (sqlite, mysql, ali postgresql).",
    "Microsoft Windows Platform is not supported" : "Okolje Microsoft Windows ni podprto.",
    "Cannot write into \"config\" directory" : "Mapa 'config' nima nastavljenih ustreznih dovoljenj za pisanje!",
    "Cannot write into \"apps\" directory" : "Mapa \"apps\" nima nastavljenih ustreznih dovoljenj za pisanje!",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Napako je mogoče odpraviti z dodelitvijo dovoljenja spletnemu strežniku %s za pisanje v mapo programov %s, ali pa z onemogočanjem nameščanja programov v nastavitveni datoteki.",
    "Cannot create \"data\" directory (%s)" : "Ni mogoče ustvariti\"podatkovne\" mape (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Napako je mogoče odpraviti z  <a href=\"%s\" target=\"_blank\">dodelitvijo dovoljenja spletnemu strežniku za pisanje v korensko mapo</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dovoljenja je mogoče odpraviti z %sdodelitvijo dovoljenja spletnemu strežniku za pisanje korensko mapo%s.",
    "Setting locale to %s failed" : "Nastavljanje jezikovnih določil na %s je spodletelo.",
    "Please install one of these locales on your system and restart your webserver." : "Namestiti je treba podporo za vsaj eno od navedenih jezikovnih določil v sistemu in nato ponovno zagnati spletni strežnik.",
    "Please ask your server administrator to install the module." : "Obvestite skrbnika strežnika, da je treba namestiti manjkajoč modul.",
    "PHP module %s not installed." : "Modul PHP %s ni nameščen.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Nastavitev PHP \"%s\" ni nastavljena na \"%s\".",
    "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
    "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
    "PostgreSQL >= 9 required" : "Zahtevana je različica PostgreSQL >= 9.",
    "Please upgrade your database version" : "Posodobite različico podatkovne zbirke.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
    "Data directory (%s) is readable by other users" : "Podatkovna mapa (%s) ima določena dovoljenja za branje skupine.",
    "Data directory (%s) is invalid" : "Podatkovna mapa (%s) ni veljavna.",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Preverite, ali je v korenu podatkovne mape datoteka \".ocdata\".",
    "Could not obtain lock type %d on \"%s\"." : "Ni mogoče pridobiti zaklepa %d na \"%s\".",
    "Storage not available" : "Shramba ni na voljo"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
